import { Signal } from "@preact/signals-core";
import { BehaviorSubject, OperatorFunction } from "rxjs";
/**
 * converts a Preact Signal into a BehaviorSubject
 * @param signal a Preact Signal of type T
 * @returns a BehaviorSubject of type T
 */
export declare const fromSignal: <T>(signal: Signal<T>) => BehaviorSubject<T>;
/**
 * converts a BehaviorSubject into a Preact Signal
 * @param bs a BehaviorSubject of type T
 * @returns a Preact Signal of type T
 */
export declare const toSignal: <T>(bs: BehaviorSubject<T>) => Signal<T>;
/**
 * Modifies a Preact Signal by any number of RxJS pipeable operators
 * @param _signal the source Preact Signal
 * @param operations RxJS pipeable operator functions
 * @returns a new Preact Signal
 */
export declare const pipeSignal: <T>(_signal: Signal<T>, ...operations: OperatorFunction<any, any>[]) => Signal<T>;
