"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pipeSignal = exports.toSignal = exports.fromSignal = void 0;
var signals_core_1 = require("@preact/signals-core");
var rxjs_1 = require("rxjs");
/**
 * converts a Preact Signal into a BehaviorSubject
 * @param signal a Preact Signal of type T
 * @returns a BehaviorSubject of type T
 */
var fromSignal = function (signal) {
    var bs = new rxjs_1.BehaviorSubject(signal.value);
    (0, signals_core_1.effect)(function () { return bs.next(signal.value); });
    return bs;
};
exports.fromSignal = fromSignal;
/**
 * converts a BehaviorSubject into a Preact Signal
 * @param bs a BehaviorSubject of type T
 * @returns a Preact Signal of type T
 */
var toSignal = function (bs) {
    var _signal = (0, signals_core_1.signal)(bs.getValue());
    bs.subscribe(function (value) { return _signal.value = value; });
    return _signal;
};
exports.toSignal = toSignal;
/**
 * Modifies a Preact Signal by any number of RxJS pipeable operators
 * @param _signal the source Preact Signal
 * @param operations RxJS pipeable operator functions
 * @returns a new Preact Signal
 */
var pipeSignal = function (_signal) {
    var operations = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        operations[_i - 1] = arguments[_i];
    }
    var bs = (0, exports.fromSignal)(_signal);
    var retSignal = (0, signals_core_1.signal)(undefined);
    // TODO: `Observable.pipe` has a complicated type signature. 
    // @ts-ignore
    bs.pipe.apply(bs, operations).subscribe(function (value) { return retSignal.value = value; });
    return retSignal;
};
exports.pipeSignal = pipeSignal;
